==> qupzilla_1.4.1.orig.tar.gz: qupzilla-1.4.1.orig/src/lib/tools/clickablelabel.h <==
/* ============================================================
* QupZilla - WebKit based browser
* Copyright (C) 2010-2012  David Rosca <nowrep@gmail.com>
*
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
* ============================================================ */
#ifndef CLICKABLELABEL_H
#define CLICKABLELABEL_H

#include <QLabel>

#include "qz_namespace.h"

class QMouseEvent;

class QT_QUPZILLA_EXPORT ClickableLabel : public QLabel
{
    Q_OBJECT
    Q_PROPERTY(QSize fixedsize READ size WRITE setFixedSize)
    Q_PROPERTY(int fixedwidth READ width WRITE setFixedWidth)
    Q_PROPERTY(int fixedheight READ height WRITE setFixedHeight)
    Q_PROPERTY(QString themeIcon READ themeIcon WRITE setThemeIcon)

public:
    explicit ClickableLabel(QWidget* parent = 0);

    void setThemeIcon(const QString &name);
    QString themeIcon() const;

signals:
    void clicked(QPoint);
    void middleClicked(QPoint);

private:
    void mouseReleaseEvent(QMouseEvent* ev);

    QString m_themeIcon;

};

#endif // CLICKABLELABEL_H

==> qupzilla_1.6.0.orig.tar.gz: qupzilla-1.6.0/src/lib/tools/clickablelabel.h <==
/* ============================================================
* QupZilla - WebKit based browser
* Copyright (C) 2010-2012  David Rosca <nowrep@gmail.com>
*
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
* ============================================================ */
#ifndef CLICKABLELABEL_H
#define CLICKABLELABEL_H

#include <QLabel>
#include <QIcon>

#include "qz_namespace.h"

class QMouseEvent;

class QT_QUPZILLA_EXPORT ClickableLabel : public QLabel
{
    Q_OBJECT
    Q_PROPERTY(QSize fixedsize READ size WRITE setFixedSize)
    Q_PROPERTY(int fixedwidth READ width WRITE setFixedWidth)
    Q_PROPERTY(int fixedheight READ height WRITE setFixedHeight)
    Q_PROPERTY(QString themeIcon READ themeIcon WRITE setThemeIcon)
    Q_PROPERTY(QIcon fallbackIcon READ fallbackIcon WRITE setFallbackIcon)

public:
    explicit ClickableLabel(QWidget* parent = 0);

    QString themeIcon() const;
    void setThemeIcon(const QString &name);

    QIcon fallbackIcon() const;
    void setFallbackIcon(const QIcon &image);

signals:
    void clicked(QPoint);
    void middleClicked(QPoint);

private:
    void mouseReleaseEvent(QMouseEvent* ev);

    QString m_themeIcon;

};

#endif // CLICKABLELABEL_H
